Welcome to clisops's documentation!
===================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    readme
    installation
    usage
    api
    configuration
    notebooks/index
    contributing
    authors
    history

.. toctree::
   :maxdepth: 2
   :caption: Package Structure

   apidoc/modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
